@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-02-18'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -854,22 +854,22 @@ sub _complete_item {
 my $_alias_spec_add_dataset = {
     summary => 'Add a dataset',
     code => sub {
-        require JSON;
+        require JSON::MaybeXS;
 
         my $args = shift;
         push @{ $args->{datasets} },
-            JSON::decode_json($_[0]);
+            JSON::MaybeXS::decode_json($_[0]);
     },
 };
 
 my $_alias_spec_add_participant = {
     summary => 'Add a participant',
     code => sub {
-        require JSON;
+        require JSON::MaybeXS;
 
         my $args = shift;
         push @{ $args->{participants} },
-            JSON::decode_json($_[0]);
+            JSON::MaybeXS::decode_json($_[0]);
     },
 };
 
@@ -905,12 +905,12 @@ sub format_result {
     $opts //= {};
 
     $formatters //= [
+        'AddVsSlowestField',
+        'RoundNumbers',
         ['Sort', {by=>$opts->{sort}}],
         'ScaleTime',
         'ScaleRate',
         ($envres->[3]{'func.module_startup'} ? ('ModuleStartup') : ()),
-        'AddVsSlowestField',
-        'RoundNumbers',
         'DeleteConstantFields',
         'DeleteNotesFieldIfEmpty',
         'DeleteSeqField',
@@ -1824,7 +1824,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.35 of Bencher (from Perl distribution Bencher), released on 2016-02-18.
+This document describes version 0.36 of Bencher (from Perl distribution Bencher), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -2117,7 +2117,7 @@ You can use this hook to, e.g.: modify the result in some way.
 
 A benchmark framework.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -2330,17 +2330,17 @@ Return value:  (any)
 
 Format bencher result.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<envres>* => I<array>
+=item * B<$envres>* => I<array>
 
 Enveloped result from bencher.
 
-=item * B<formatters>* => I<array[str|array]>
+=item * B<$formatters>* => I<array[str|array]>
 
 Formatters specification.
 
@@ -2362,7 +2362,7 @@ Return value:  (any)
 
 Parse scenario (fill in default values, etc).
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
