@@ -1,7 +1,7 @@
 package Sah::Schema::Bencher::Scenario;
 
-our $DATE = '2016-02-18'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use strict;
 use warnings;
@@ -66,7 +66,7 @@ Sah::Schema::Bencher::Scenario - Sah schemas to validate Bencher specifications
 
 =head1 VERSION
 
-This document describes version 0.35 of Sah::Schema::Bencher::Scenario (from Perl distribution Bencher), released on 2016-02-18.
+This document describes version 0.36 of Sah::Schema::Bencher::Scenario (from Perl distribution Bencher), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -76,6 +76,14 @@ This document describes version 0.35 of Sah::Schema::Bencher::Scenario (from Per
 
 This module contains L<Sah> schemas to validate L<Bencher>.
 
+=head1 SAH SCHEMAS
+
+=over
+
+=item * bencher_scenario
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher>.
@@ -94,6 +102,10 @@ feature.
 
 =head1 SEE ALSO
 
+L<Sah> - specification
+
+L<Data::Sah>
+
 L<Bencher>
 
 =head1 AUTHOR
